@@ -3,12 +3,11 @@ from norse.torch.functional.heaviside import heaviside
 
 
 class SuperSpike(torch.autograd.Function):
-    """SuperSpike surrogate gradient as described in Section 3.3.2 of
+    r"""SuperSpike surrogate gradient as described in Section 3.3.2 of
 
-    F. Zenke, S. Ganguli, "SuperSpike: Supervised Learning in
-                           Multilayer Spiking Neural Networks",
+    F. Zenke, S. Ganguli, **"SuperSpike: Supervised Learning in Multilayer Spiking Neural Networks"**,
     Neural Computation 30, 1514–1541 (2018),
-    doi:10.1162/neco_a_01086
+    `doi:10.1162/neco_a_01086 <https://www.mitpressjournals.org/doi/full/10.1162/neco_a_01086>`_
     """
 
     @staticmethod
